@@ -1,6 +1,9 @@
 package Email::Send::Qmail;
 use strict;
 
+our $VERSION = '2.202';
+$VERSION = eval $VERSION;
+
 use File::Spec ();
 BEGIN {
   local $Return::Value::NO_CLUCK = 1;
@@ -9,9 +12,8 @@ BEGIN {
 }
 use Symbol qw(gensym);
 
-use vars qw[$QMAIL $VERSION];
+use vars qw[$QMAIL];
 $QMAIL   ||= q[qmail-inject];
-$VERSION   = '2.200';
 
 sub is_available {
     my $class = shift;
@@ -87,14 +89,27 @@ L<perl>.
 
 =head1 AUTHOR
 
-Current maintainer: Ricardo SIGNES, <F<rjbs@cpan.org>>.
+Casey West, <F<casey@geeknest.com>>.
 
-Original author: Casey West, <F<casey@geeknest.com>>.
+=head1 CONTRIBUTORS
 
-=head1 COPYRIGHT
+=over
 
-  Copyright (c) 2004 Casey West.  All rights reserved.
-  This module is free software; you can redistribute it and/or modify it
-  under the same terms as Perl itself.
+=item *
+
+Chase Whitener, <F<capoeirab@cpan.org>>.
+
+=item *
+
+Ricardo SIGNES, <F<rjbs@cpan.org>>.
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2004 Casey West.  All rights reserved.
+
+This module is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
