@@ -1,6 +1,9 @@
 package Email::Send::Sendmail;
 use strict;
 
+our $VERSION = '2.202';
+$VERSION = eval $VERSION;
+
 use File::Spec ();
 BEGIN {
   local $Return::Value::NO_CLUCK = 1;
@@ -9,9 +12,7 @@ BEGIN {
 }
 use Symbol qw(gensym);
 
-use vars qw[$SENDMAIL $VERSION];
-
-$VERSION   = '2.201';
+use vars qw[$SENDMAIL];
 
 sub is_available {
     my $class = shift;
@@ -53,7 +54,7 @@ sub send {
 
     return failure "Found $mailer but cannot execute it"
         unless -x $mailer;
-    
+
     local $SIG{'CHLD'} = 'DEFAULT';
 
     my $pipe = gensym;
@@ -98,14 +99,27 @@ L<perl>.
 
 =head1 AUTHOR
 
-Current maintainer: Ricardo SIGNES, <F<rjbs@cpan.org>>.
+Casey West, <F<casey@geeknest.com>>.
 
-Original author: Casey West, <F<casey@geeknest.com>>.
+=head1 CONTRIBUTORS
 
-=head1 COPYRIGHT
+=over
 
-  Copyright (c) 2004 Casey West.  All rights reserved.
-  This module is free software; you can redistribute it and/or modify it
-  under the same terms as Perl itself.
+=item *
+
+Chase Whitener, <F<capoeirab@cpan.org>>.
+
+=item *
+
+Ricardo SIGNES, <F<rjbs@cpan.org>>.
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (c) 2004 Casey West.  All rights reserved.
+
+This module is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
 
 =cut
